@@ -1,4 +1,4 @@
-"""VCP CLI - A command-line interface (CLI) to the Chan Zuckerberg Initiative's Virtual Cell Platform (VCP)"""
+"""VCP CLI - A command-line interface (CLI) to the Chan Zuckerberg Initiative's Virtual Cells Platform (VCP)"""
 
 import importlib.metadata
 
