@@ -16,6 +16,7 @@ from ...auth.github import GitHubAuth
 from ...config.config import Config
 from ...utils.token import TokenManager
 from .git_operations import GitOperations
+from .models import SubmissionResponse
 from .utils import validate_version_format
 from .workspace import ModelWorkspaceState
 
@@ -686,19 +687,19 @@ def init_command(
             # Model doesn't exist - create new repository via API
             console.print("[yellow]Model doesn't exist. Creating new model...[/yellow]")
 
-            # Call model hub API to create new repository
-            create_url = f"{model_hub_url}/api/github/contribution/create-repo"
+            # Call model hub API to create new submission
+            create_url = f"{model_hub_url}/api/sub"
             create_data = {
                 "model_name": model_name,
                 "model_version": model_version,
                 "license_type": license_type,
             }
-            _verbose_print(f"Create repository URL: {create_url}", verbose)
+            _verbose_print(f"Create submission URL: {create_url}", verbose)
             _verbose_print(f"Create data: {create_data}", verbose)
 
             # Get authentication headers for API calls
             _verbose_print(
-                "Getting authentication headers for repository creation", verbose
+                "Getting authentication headers for submission creation", verbose
             )
             token_manager = TokenManager()
             headers = token_manager.get_auth_headers()
@@ -707,7 +708,7 @@ def init_command(
                 console.print("[red]Not logged in. Please run 'vcp login' first.[/red]")
                 return
 
-            _verbose_print("Making API request to create repository", verbose)
+            _verbose_print("Making API request to create submission", verbose)
             create_response = requests.post(
                 create_url, json=create_data, headers=headers
             )
@@ -715,10 +716,18 @@ def init_command(
                 f"Create response status: {create_response.status_code}", verbose
             )
             create_response.raise_for_status()
-            create_result = create_response.json()
-            _verbose_print(f"Create result: {create_result}", verbose)
 
-            repo_url = create_result.get("repo_url")
+            # Parse response using Pydantic model
+            submission_response = SubmissionResponse.model_validate(
+                create_response.json()
+            )
+            _verbose_print(
+                f"Create result: {submission_response.model_dump()}", verbose
+            )
+
+            # Extract submission data from validated response
+            repo_url = submission_response.submission.repo_url
+            submission_id = submission_response.submission.submission_id
             console.print("[green]New model created[/green]")
 
             # Clone the newly created repository
@@ -756,7 +765,7 @@ def init_command(
                 _verbose_print(f"Traceback: {traceback.format_exc()}", verbose)
                 return
 
-            # Create .model-metadata file with branch information
+            # Create .model-metadata file with branch information and submission_id
             metadata = {
                 "model_name": model_name,
                 "model_version": model_version,
@@ -767,6 +776,7 @@ def init_command(
                 "template_repo": config_data.models.github.template_repo,
                 "created_at": datetime.utcnow().isoformat(),
                 "last_updated": datetime.utcnow().isoformat(),
+                "submission_id": submission_id,  # Save submission_id from API response
             }
             workspace.save_state(metadata)
             console.print("[blue]Created model configuration[/blue]")
