@@ -743,7 +743,7 @@ def submit_command(
                 str(Path(config) if config else Path.home() / ".vcp" / "config.yaml"),
             )
             table.add_row("API Base URL", config_data.models.base_url)
-            table.add_row("Model Hub Submit Endpoint", "/api/models/register")
+            table.add_row("Model Hub Submit Endpoint", "/api/sub/submit")
 
             console.print(table)
 
@@ -887,7 +887,20 @@ def submit_command(
             console.print(json.dumps(safe_data, indent=2))
 
         # Submit to VCP Model Hub API
-        url = f"{config_data.models.base_url}/api/models/register"
+        url = f"{config_data.models.base_url}/api/sub/submit"
+
+        # Build request body - Always send model_name + model_version (API uses these to generate/validate ID)
+        # Optionally include submission_id if available for validation
+        request_body = {
+            "model_name": metadata["model_name"],
+            "model_version": metadata["model_version"],
+            "skip_packaging": False,  # Model needs packaging by default
+        }
+
+        submission_id = metadata.get("submission_id")
+        if submission_id:
+            # Include submission_id for validation (API will verify it matches model_name+version)
+            request_body["submission_id"] = submission_id
 
         if verbose:
             console.print(
@@ -899,10 +912,13 @@ def submit_command(
             if "Authorization" in safe_headers:
                 safe_headers["Authorization"] = "Bearer ***MASKED***"
             console.print("Headers:", json.dumps(safe_headers, indent=2))
+            console.print(
+                f"Submitting: {metadata['model_name']} v{metadata['model_version']}"
+            )
+            if submission_id:
+                console.print(f"  (with submission_id: {submission_id})")
 
         # Make API request to VCP Model Hub
-        # Wrap data in "data" field as expected by the API
-        request_body = {"data": data}
         response = requests.post(url, json=request_body, headers=headers)
 
         if verbose:
