@@ -20,10 +20,12 @@ from rich.progress import (
     TextColumn,
     TimeElapsedColumn,
 )
+from rich.table import Table
 
 from ...auth.github import GitHubAuth
 from ...config.config import Config
 from ...utils.cache import get_vcp_cache_dir
+from .models import ModelResponse
 
 console = Console()
 
@@ -1720,3 +1722,42 @@ class GitHubPRFeedback:
                     summary_parts.append(f"    - {author} ({state})")
 
         return "\n".join(summary_parts)
+
+
+def format_models_table(models: list[ModelResponse]) -> Table:
+    """
+    Format models list as a Rich table.
+
+    Args:
+        models: List of ModelResponse objects
+
+    Returns:
+        Rich Table ready for console.print()
+    """
+    table = Table(show_header=True, header_style="bold magenta")
+    table.add_column("Model Name")
+    table.add_column("Version")
+    table.add_column("Description")
+
+    for model in models:
+        if model.versions:
+            # Add first version with model name
+            first_version = model.versions[0]
+            table.add_row(
+                model.name,
+                first_version.version,
+                first_version.description or "N/A",
+            )
+
+            # Add remaining versions with empty model name
+            for version in model.versions[1:]:
+                table.add_row(
+                    "",
+                    version.version,
+                    version.description or "N/A",
+                )
+        else:
+            # Model with no versions
+            table.add_row(model.name, "No versions", "N/A")
+
+    return table
