@@ -216,9 +216,10 @@ def s3_stream_batch(
         test_uri = s3_uri[0]
         parsed = urlparse(test_uri)
         bucket_name = parsed.netloc
+        prefix = parsed.path.lstrip("/")
 
         try:
-            s3.head_bucket(Bucket=bucket_name)
+            s3.list_objects_v2(Bucket=bucket_name, Prefix=prefix, MaxKeys=1)
         except ClientError as e:
             error_code = e.response.get("Error", {}).get("Code", "")
             if error_code in {"403", "AccessDenied"}:
